@@ -209,7 +209,7 @@ public abstract class Builder {
         if (constructor != null) {
             // 指定されたコンストラクタでインスタンスを生成。
             return ObjectUtils.getInstance(type, constructor.getClasses(),
-                    constructor.getArguments());
+                    constructor.getArguments(), constructor.isFuzzy());
         } else {
             // デフォルトコンストラクタでインスタンスを生成。
             return ObjectUtils.getObject(type);
@@ -226,7 +226,7 @@ public abstract class Builder {
         if (constructor != null) {
             // 指定されたコンストラクタでインスタンスを生成。
             return ObjectUtils.getInstance(type, constructor.getClasses(),
-                    constructor.getArguments());
+                    constructor.getArguments(), constructor.isFuzzy());
         } else {
             // デフォルトコンストラクタでインスタンスを生成。
             return ObjectUtils.getObject(type);
