@@ -38,7 +38,7 @@ public class ClassBuilder extends Builder {
             String name = getRequiredName(child);
             Argument argument = ArgumentBuilder.getArgument(child);
             ObjectUtils.invokeMethod(object, name, argument.getClasses(),
-                    argument.getArguments());
+                    argument.getArguments(), argument.isFuzzy());
         }
 
         // オブジェクトを返す。
