@@ -105,6 +105,16 @@ public class Config {
         return getBooleanProperty(INSPECTION_PROP_KEY_PRIFIX + "class", true);
     }
 
+    /**
+     * 例外のクラスを検査するかどうかを返す。
+     * 
+     * @return 検査する場合はtrue
+     */
+    public static boolean isInspectionExceptionClass() {
+        return getBooleanProperty(INSPECTION_PROP_KEY_PRIFIX
+                + "exception.class", true);
+    }
+
     /**
      * 例外の原因を検査するかどうかを返す。
      * 
@@ -266,9 +276,9 @@ public class Config {
      * 
      * @return 無視するディレクトリのリスト
      */
-    public static List getTestIgnoreDirs() {
+    public static List getTestIgnores() {
         // ディレクトリのリストを取得。
-        String dirs = getProperty(TEST_PROP_KEY_PREFIX + "ignore.dirs");
+        String dirs = getProperty(TEST_PROP_KEY_PREFIX + "ignores");
 
         // 未定義の場合は空のリストを返す。
         if (dirs == null) {
@@ -537,6 +547,15 @@ public class Config {
         // 設定ファイルを読み込む。
         load(DEFAULT_CONFIG_FILE_NAME, true);
         load(CONFIG_FILE_NAME, false);
+
+        // 設定ファイルをインクルード。
+        String includeList = getProperty("&include");
+        String[] includes = getList(includeList);
+
+        for (int i = 0; i < includes.length; i++) {
+            load(includes[i], false);
+        }
+
         // システムプロパティを読み込む。
         config.putAll(System.getProperties());
     }
