@@ -187,6 +187,19 @@ public class ObjectUtils {
         return clazz;
     }
 
+    /**
+     * インスタンスを取得する。
+     * 
+     * @param type クラス名
+     * @param classes コンストラクタの引数の型
+     * @param arguments コンストラクタの引数
+     * @return インスタンス
+     */
+    public static Object getInstance(String type, Class[] classes,
+            Object[] arguments) {
+        return getInstance(type, classes, arguments, false);
+    }
+
     /**
      * インスタンスを取得する。
      * 
@@ -202,6 +215,19 @@ public class ObjectUtils {
         return getInstance(clazz, classes, arguments, search);
     }
 
+    /**
+     * インスタンスを取得する。
+     * 
+     * @param clazz クラス
+     * @param classes コンストラクタの引数の型
+     * @param arguments コンストラクタの引数
+     * @return インスタンス
+     */
+    public static Object getInstance(Class clazz, Class[] classes,
+            Object[] arguments) {
+        return getInstance(clazz, classes, arguments, false);
+    }
+
     /**
      * インスタンスを取得する。
      * 
@@ -230,6 +256,17 @@ public class ObjectUtils {
         }
     }
 
+    /**
+     * コンストラクタを取得する。
+     * 
+     * @param clazz クラス
+     * @param types パラメータの型
+     * @return コンストラクタ
+     */
+    public static Constructor getConstructor(Class clazz, Class[] types) {
+        return getConstructor(clazz, types, false);
+    }
+
     /**
      * コンストラクタを取得する。
      * 
@@ -242,9 +279,17 @@ public class ObjectUtils {
             boolean search) {
         try {
             if (types == null || types.length < 1) {
-                return clazz.getConstructor(new Class[0]);
+                try {
+                    return clazz.getConstructor(new Class[0]);
+                } catch (NoSuchMethodException e) {
+                    return clazz.getDeclaredConstructor(new Class[0]);
+                }
             } else if (!search) {
-                return clazz.getConstructor(types);
+                try {
+                    return clazz.getConstructor(types);
+                } catch (NoSuchMethodException e) {
+                    return clazz.getDeclaredConstructor(types);
+                }
             }
 
             Constructor constructor = null;
@@ -695,6 +740,30 @@ public class ObjectUtils {
     /////////////////////////////////////////////////////////////////
     // method utility
 
+    /**
+     * メソッドを取得する。
+     * 
+     * @param clazz クラス
+     * @param name メソッド名
+     * @param classes 引数のクラス
+     * @return メソッド
+     */
+    public static Method getMethod(Class clazz, String name, Class[] classes) {
+        return getMethod(clazz, name, classes, false);
+    }
+
+    /**
+     * メソッドを取得する。
+     * 
+     * @param object オブジェクト
+     * @param name メソッド名
+     * @param classes 引数のクラス
+     * @return メソッド
+     */
+    public static Method getMethod(Object object, String name, Class[] classes) {
+        return getMethod(object, name, classes, false);
+    }
+
     /**
      * メソッドを取得する。
      * 
@@ -726,9 +795,17 @@ public class ObjectUtils {
             boolean search) {
         try {
             if (types == null || types.length < 1) {
-                return clazz.getMethod(name, new Class[0]);
+                try {
+                    return clazz.getMethod(name, new Class[0]);
+                } catch (NoSuchMethodException e) {
+                    return clazz.getDeclaredMethod(name, new Class[0]);
+                }
             } else if (!search) {
-                return clazz.getMethod(name, types);
+                try {
+                    return clazz.getMethod(name, types);
+                } catch (NoSuchMethodException e) {
+                    return clazz.getDeclaredMethod(name, types);
+                }
             }
 
             Method method = null;
